Name:           mscgen
Version:        0.20
Release:        3%{?dist}
Group:          Development/Tools
Summary:        Message Sequence Chart rendering program
License:        GPLv2+
URL:            http://www.mcternan.me.uk/mscgen/
Source0:        http://www.mcternan.me.uk/mscgen/software/%{name}-src-%{version}.tar.gz

# Removes unknown escape sequence '\-'
# Patch sent upstream.
# http://code.google.com/p/mscgen/issues/detail?id=72
Patch0:         %{name}-0.20-escape.patch

# Fixes 'ymax' variable initialization
# http://code.google.com/p/mscgen/issues/detail?id=73
Patch1:         %{name}-0.20-uninitialized-ymax.patch


%global test_with_valgrind %{?_with_valgrind:1}%{!?_with_valgrind:0}


BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  pkgconfig
BuildRequires:  gd-devel
BuildRequires:  freetype-devel
BuildRequires:  urw-fonts

%if %{test_with_valgrind}
BuildRequires:  valgrind
%endif

# Freetype based font rendering requires some fonts to be installed.
Requires:       urw-fonts


%description
Mscgen is a small program that parses Message Sequence Chart descriptions
and produces PNG, SVG, EPS or server side image maps (ismaps) as the output.
Message Sequence Charts (MSCs) are a way of representing entities and
interactions over some time period and are often used in combination with SDL.
MSCs are popular in Telecoms to specify how protocols operate although MSCs
need not be complicated to create or use. Mscgen aims to provide a simple text
language that is clear to create, edit and understand, which can also be
transformed into common image formats for display or printing.


%prep
%setup -q
%patch0 -p1 -b .escape
%patch1 -p1 -b .initialization
#this ensures that they get regenerated
rm -f src/language.{c,h} src/lexer.c


%build
# Correct EOL.
sed -i 's/\r//' TODO
%configure \
    --with-freetype \
    --docdir=%{_defaultdocdir}/%{name}-%{version}
make %{?_smp_mflags}


%check
%if %{test_with_valgrind}
export VALGRIND="valgrind -v --track-origins=yes --tool=memcheck"
%endif
make check


%install
make install INSTALL="install -p" DESTDIR=%{buildroot}
cp -p TODO %{buildroot}%{_defaultdocdir}/%{name}-%{version}


%files
# due to this entry, doc must not be used to add any other files
%{_defaultdocdir}/%{name}-%{version}/
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*


%changelog
* Mon Aug 16 2012 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.20-3
- use force option while removing files,
- install TODO file,
- use %%{name} macro on PatchX,
- preserve timestamps while installing files,
- add a comment about the uwr-fonts requirement,
- backport fix for variable initialization.

* Fri Jul 20 2012 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 0.20-2
- remove superfluous spaces from the spec file,
- correct the Group,
- use consistently marcos,
- unknown escape sequence removal patch added,
- remove files which has to be regenerated,
- build with the free-type support,
- add a possibility to run tests under valgrind.

* Mon Jan 3 2011 Michael McTernan <Michael.McTernan.2001@cs.bris.ac.uk> 0.19-2
- Add comment in spec file warning of doc use.

* Wed Sep 15 2010 Michael McTernan <Michael.McTernan.2001@cs.bris.ac.uk> 0.19-1
- Version bump following upstream release.

* Tue Sep 07 2010 Michael McTernan <Michael.McTernan.2001@cs.bris.ac.uk> 0.18-3
- Further Fedora packaging fixes to remove duplicate doc (bug #630754#c4).

* Tue Sep 07 2010 Michael McTernan <Michael.McTernan.2001@cs.bris.ac.uk> 0.18-2
- Fixes from Fedora packaging review (bug #630754).

* Thu Aug 25 2010 Michael McTernan <Michael.McTernan.2001@cs.bris.ac.uk> 0.18-1
- Initial version.
